%define major   7
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:           superlu
Version:        7.0.0
Release:        %mkrel 1
Summary:        A set of subroutines to solve a sparse linear system A*X=B
License:        BSD and GPLv2+
Group:          Sciences/Mathematics
Url:            https://github.com/xiaoyeli/superlu
Source0:        https://github.com/xiaoyeli/superlu/archive/v%{version}/%{name}-%{version}.tar.gz
# ALT Patch
Patch10:        superlu-6.0.1-respect-flags.patch

BuildRequires:  cmake
BuildRequires:  csh
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  ghostscript-utils
BuildRequires:  metis-devel
BuildRequires:  pkgconfig(blas)

%description
SuperLU contains a set of subroutines to solve a sparse linear system
A*X=B. It uses Gaussian elimination with partial pivoting (GEPP).
The columns of A may be preordered before factorization; the
preordering for sparsity is completely separate from the factorization.
SuperLU provides functionality for both real and complex matrices, in both
single and double precision.

%package -n %{libname}
Summary:        A set of subroutines to solve a sparse linear system A*X=B
Group:          System/Libraries

%description -n %{libname}
SuperLU contains a set of subroutines to solve a sparse linear system
A*X=B. It uses Gaussian elimination with partial pivoting (GEPP).
The columns of A may be preordered before factorization; the
preordering for sparsity is completely separate from the factorization.
SuperLU provides functionality for both real and complex matrices, in both
single and double precision.

This package contains shared libraries of SuperLU.

%package -n %{devname}
Summary:        Development files of SuperLU
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
This package contains development files of SuperLU.

%package doc
Summary:        Documentation for SuperLU
Group:          Documentation
BuildArch:      noarch

%description doc
This package contains documentation for SuperLU.

%prep
%autosetup -p1

# Remove bundled BLAS
rm -rf CBLAS

%build
%cmake \
        -DCMAKE_BUILD_TYPE:STRING=Release \
        -DCMAKE_INSTALL_INCLUDEDIR:PATH="include/superlu" \
        -DBUILD_SHARED_LIBS:BOOL=ON \
        -Denable_internal_blaslib:BOOL=OFF \
        -DTPL_BLAS_LIBRARIES=-lblas \
        -DTPL_ENABLE_METISLIB:BOOL=ON \
        -DTPL_METIS_INCLUDE_DIRS:PATH=%{_includedir} \
        -DTPL_METIS_LIBRARIES:FILEPATH=%{_libdir}/libmetis.so \
        -DCMAKE_SKIP_RPATH:BOOL=YES \
        -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES

%cmake_build

%install
%cmake_install

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}:MATGEN
%ctest

%files -n %{libname}
%doc License.txt
%doc README
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/cmake/%{name}/

%files doc
%doc DOC/html
%doc EXAMPLE
%doc FORTRAN


%changelog
* Mon Sep 09 2024 daviddavid <daviddavid> 7.0.0-1.mga10
+ Revision: 2094581
- new version: 7.0.0
- now libmajor is 7

* Sat Feb 17 2024 daviddavid <daviddavid> 6.0.1-1.mga10
+ Revision: 2042072
- new version: 6.0.1
+ wally <wally>
- fix devel pkg requires
- rename src rpm as superlu
- libify pkg
- drop doc pkg
- fix build
+ shlomif <shlomif>
- Fix deps
- Importing based on Fedora

